Changelog
=========

0.2.2 (2025-02-10)
------------------
- Add reference to the System.ServiceProcess
- Copyright year update.

0.2.0 (2025-02-02)
------------------
- Copyright year update.
- Tox configuration is now in native (toml) format.
- Setup (dependencies) update.

0.1.0 (2024-10-30)
------------------
- First release.

0.0.0 (2024-08-13)
------------------
- Initial commit.
